pub struct Conceal { /* private fields */ }Implementations
Sourceimpl Conceal
impl Conceal
pub const GUESS_MVS: Conceal
pub const DEBLOCK: Conceal
pub const FAVOR_INTER: Conceal
Sourcepub fn from_bits(bits: c_int) -> Option<Conceal>
pub fn from_bits(bits: c_int) -> Option<Conceal>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: c_int) -> Conceal
pub const fn from_bits_truncate(bits: c_int) -> Conceal
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: c_int) -> Conceal
pub const unsafe fn from_bits_unchecked(bits: c_int) -> Conceal
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: Conceal) -> bool
pub const fn intersects(&self, other: Conceal) -> bool
Returns true if there are flags common to both self and other.