pub struct Flags { /* private fields */ }Implementations
Sourceimpl Flags
impl Flags
pub const CODED_ORDER: Flags
pub const ALLOW_FIELD: Flags
pub const ALLOW_PLANE: Flags
Sourcepub fn from_bits(bits: c_int) -> Option<Flags>
pub fn from_bits(bits: c_int) -> Option<Flags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: c_int) -> Flags
pub const fn from_bits_truncate(bits: c_int) -> Flags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: c_int) -> Flags
pub const unsafe fn from_bits_unchecked(bits: c_int) -> Flags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: Flags) -> bool
pub const fn intersects(&self, other: Flags) -> bool
Returns true if there are flags common to both self and other.